<!doctype html>
<html lang="{{ DEFAULT_LANG }}">
<head>

<meta charset="utf-8">
<title>
  {%- if title is defined %}
    {{- title }} - {{ SITENAME -}}
  {% else %}
    {{- SITENAME -}}
  {% endif -%}
</title>

</head>
<body>

{% block body %}{% endblock %}

</body>
</html>
