{% set article_list = articles_page.object_list %}
{% set title = author.name %}
{% set current_page = articles_page %}
{% set paginator = articles_paginator %}
{% extends "include/article_list_page.html" %}
