{# Requires variables `article_list` and `title` to be defined. #}
{# Optionally, define both `current_page` and `paginator` object. #}
{% extends "include/base.html" %}

{% block body %}
  <h1>{{ title }}</h1>
  <table>
    <thead>
      <tr>
        <th>Title</th>
        <th>Date</th>
      </tr>
    </thead>
    <tbody>
      {% for article in article_list %}
        <tr>
          <td>
            <a href="{{ SITEURL }}/{{ article.url }}">
              {{ article.title }}
            </a>
          </td>
          {% if article.locale_date %}
            <td>{{ article.locale_date }}</td>
          {% endif %}
        </tr>
      {% endfor %}
    </tbody>
  </table>
  {% if paginator is defined and current_page is defined %}
    {% include "include/paginator.html" %}
  {% endif %}
{% endblock %}
